==> aioalfacrm-0.2.1-py3-none-any.whl: aioalfacrm/managers/customer_tariff.py <==
import typing

from ..core import EntityManager

T = typing.TypeVar('T')


class CustomerTariff(EntityManager, typing.Generic[T]):
    object_name = 'customer-tariff'

    async def list(
            self,
            customer_id: typing.Optional[int] = None,
            page: int = 0,
            count: int = 100,
            *args,
            **kwargs
    ) -> typing.List[T]:
        if customer_id is None:
            raise ValueError(f'customer_id is not filled')
        raw_result = await self._list(
            page=page,
            count=count,
            params={
                'customer_id': customer_id,
            },
            **kwargs,
        )

        return [self._entity_class(id_=item.pop('id'), **item) for item in raw_result['items']]

    async def get(
            self,
            id_: int,
            customer_id: typing.Optional[int] = None,
            **kwargs,
    ) -> T:
        if customer_id is None:
            raise ValueError(f'customer_id is not filled')
        raw_result = await self._get(
            id_=id_,
            params={
                'customer_id': customer_id,
            },
            **kwargs,
        )

        return self._entity_class(id_=raw_result.pop('id'), **raw_result)

    async def save(
            self,
            model: T,
            customer_id: typing.Optional[int] = None,
    ) -> T:
        raw_result = await self._save(
            params={
                'customer_id': customer_id,
            },
            **model.serialize()
        )

        return self._entity_class(id_=raw_result.pop('id'), **raw_result)

==> aioalfacrm-0.3.2-py3-none-any.whl: aioalfacrm/managers/customer_tariff.py <==
import typing

from ..core import EntityManager

T = typing.TypeVar('T')


class CustomerTariff(EntityManager, typing.Generic[T]):
    object_name = 'customer-tariff'

    async def list(
            self,
            customer_id: typing.Optional[int] = None,
            page: int = 0,
            count: int = 100,
            *args,
            **kwargs
    ) -> typing.List[T]:
        if customer_id is None:
            raise ValueError(f'customer_id is not filled')
        result = await self._list(
            page=page,
            count=count,
            params={
                'customer_id': customer_id,
            },
            **kwargs,
        )

        return self._result_to_entities(result)

    async def get(
            self,
            id_: int,
            customer_id: typing.Optional[int] = None,
            **kwargs,
    ) -> T:
        if customer_id is None:
            raise ValueError(f'customer_id is not filled')
        result = await self._get(
            id_=id_,
            params={
                'customer_id': customer_id,
            },
            **kwargs,
        )

        return self._result_to_entity(result)

    async def save(
            self,
            model: T,
            customer_id: typing.Optional[int] = None,
    ) -> T:
        result = await self._save(
            params={
                'customer_id': customer_id,
            },
            **model.serialize()
        )

        return self._result_to_entity(result)
